--- cgi/status.c.orig	2008-07-29 21:11:44.000000000 +0200
+++ cgi/status.c	2008-07-30 19:33:03.000000000 +0200
@@ -125,6 +125,9 @@
 
 void show_filters(void);
 
+void create_orphan_hosts_hostgroup();
+void create_orphan_services_servicegroup();
+
 int passes_host_properties_filter(hoststatus *);
 int passes_service_properties_filter(servicestatus *);
 
@@ -240,6 +243,10 @@
 	/* get authentication information */
 	get_authentication_information(&current_authdata);
 
+	/* create a new hostgroup with orphaned hosts and a servicegroup with orphaned services */
+	create_orphan_hosts_hostgroup();
+	create_orphan_services_servicegroup();
+
 	/* if a navbar search was performed, find the host by name, address or partial name */
 	if(navbar_search==TRUE){
 		if((temp_host=find_host(host_name))==NULL){
@@ -5199,3 +5206,62 @@
         }
 
 
+/* Creates a hostgroup with hosts which are not a member of any hostgroup */
+void create_orphan_hosts_hostgroup() {
+
+    hostgroup *orphan_hostgroup;
+    host *temp_host;
+    hostgroup *temp_hostgroup;
+
+    orphan_hostgroup = add_hostgroup("orphans","Orphan Hosts","","","");
+
+    if (orphan_hostgroup) {
+        for (temp_host=host_list;temp_host!=NULL;temp_host=temp_host->next) {
+            int found = 0;
+            for (temp_hostgroup=hostgroup_list;temp_hostgroup!=NULL;temp_hostgroup=temp_hostgroup->next) {
+                hostsmember *member;
+                for (member=temp_hostgroup->members;member!=NULL;member=member->next) {
+                    // Remember we have found this host
+                    if (strcmp(member->host_name,temp_host->name)==0)
+                        found++;
+                }
+            }
+            // If we didn't find this host in any hostgroup, this is an orphaned host
+            if (found==0) {
+                add_host_to_hostgroup(orphan_hostgroup,temp_host->name);
+            }
+        }
+    }
+
+}
+
+
+/* Creates a servicegroup with services which are not a member of any servicegroup */
+void create_orphan_services_servicegroup() {
+
+    servicegroup *orphan_servicegroup;
+    service *temp_service;
+    servicegroup *temp_servicegroup;
+
+    orphan_servicegroup = add_servicegroup("orphans","Orphan Services","","","");
+
+    if (orphan_servicegroup) {
+        for (temp_service=service_list;temp_service!=NULL;temp_service=temp_service->next) {
+            int found = 0;
+            for (temp_servicegroup=servicegroup_list;temp_servicegroup!=NULL;temp_servicegroup=temp_servicegroup->next) {
+                servicesmember *member;
+                for (member=temp_servicegroup->members;member!=NULL;member=member->next) {
+                    // Remember we have found this host
+                    if (strcmp(member->service_description,temp_service->description)==0)
+                        found++;
+                }
+            }
+            // If we didn't find this service in any servicegroup, this is an orphaned service
+            if (found==0) {
+                add_service_to_servicegroup(orphan_servicegroup,temp_service->host_name,temp_service->description);
+            }
+        }
+    }
+
+}
+
